
# Subset: owl


Set of slots that appear in the OWL representation of a model

URI: [linkml:owl](https://w3id.org/linkml/owl)


### Classes


### Mixins


### Slots

 * comments
 * description
 * [examples](examples.md) - example usages of an element
 * generation_date
 * license
 * metamodel_version
 * name
 * notes
 * schema_definition_name
 * see_also
 * source_file
 * source_file_date
 * source_file_size
 * title
 * version

### Types


### Enums

